@@ -7,7 +7,7 @@ import xlrd
 from loguru import logger
 from minio import Minio, ResponseError
 
-from miniMinio.utils import get_minio_object, get_attributes_local, get_attributes_single_local
+from miniMinio.utils import get_attributes_minio, get_attributes_local, get_attributes_single_local
 
 exclude = {".minio.sys"}
 
@@ -92,16 +92,16 @@ def get_all_object_details_in_bucket(client, bucket_name=None, attributes=None,
         for s3_object in all_objects:
             # Check if folder
             if (s3_object.is_dir) and ("folder" in filter_object):
-                store.append(s3_object)
+                store = get_attributes_minio(attributes, s3_object, store)
                 continue
             # Check if file
             elif (not s3_object.is_dir) and ("file" in filter_object):
                 if ext is None:
-                    store.append(s3_object)
+                    store = get_attributes_minio(attributes, s3_object, store)
                 else:
                     filename, filename_ext = os.path.splitext(s3_object.object_name)
                     if filename_ext in ext:
-                        store.append(s3_object)
+                        store = get_attributes_minio(attributes, s3_object, store)
 
     return store
 
@@ -128,7 +128,7 @@ def get_object_details_in_bucket(client, object_name, bucket_name=None, attribut
             if object_name.lower() not in s3_object.object_name.lower():
                 continue
             else:
-                store = get_minio_object(attributes, s3_object, store)
+                store = get_attributes_minio(attributes, s3_object, store)
     return store[0]
 
 
@@ -152,6 +152,51 @@ def get_object_path(client, bucket_name, filename):
     return output
 
 
+def get_objects_in_bucket(client, bucket_name=None,
+                              filter_object=("file", "folder"), filter_prefix = '', ext=None):
+    """
+    :param client: Minio connection object
+    :param bucket_name: str bucket name, or file path of root to start search from
+    :param filter_object: tuple of str - 'file', 'folder'
+    :param ext: tuple of str - desired extensions
+    :return:
+    """
+    if ext is not None:
+       ext = ["."+ex for ex in ext]
+    store = []
+    if client == "local" or client == "remote":
+        if client is "local":
+            bucket_name = os.getcwd()
+        bucket_name = os.path.join(bucket_name, filter_prefix)
+        for path, subdirs, files in os.walk(bucket_name, topdown=True):
+            subdirs[:] = set(subdirs) - exclude
+            if "file" in filter_object:
+                # file
+                for file in files:
+                    with open(os.path.join(path, file), "rb") as f:
+                        store.append(f.read())
+            if "folder" in filter_object:
+                for subdir in subdirs:
+                    with open(os.path.join(path, subdir), "rb") as f:
+                        store.append(f.read())
+    else:
+        all_objects = client.list_objects(bucket_name, prefix=filter_prefix, recursive=True)
+        for s3_object in all_objects:
+            # Check if folder
+            if (s3_object.is_dir) and ("folder" in filter_object):
+                store.append(s3_object)
+                continue
+            # Check if file
+            elif (not s3_object.is_dir) and ("file" in filter_object):
+                if ext is None:
+                    store.append(s3_object)
+                else:
+                    filename, filename_ext = os.path.splitext(s3_object.object_name)
+                    if filename_ext in ext:
+                        store.append(s3_object)
+    return store
+
+
 def get_single_object_from_bucket_to_file(client, object_name, dir_path, bucket_name=None):
     """
     :param client:
