@@ -3,8 +3,11 @@ import os
 import time
 
 
-def get_minio_object(attributes, s3_object, store):
-    store.append(s3_object)
+def get_attributes_minio(attributes, s3_object, store):
+    attribute_list = []
+    for attribute in attributes:
+        attribute_list.append(getattr(s3_object, attribute))
+    store.append(tuple(attribute_list))
     return store
 
 
